==> haskell-monad-dijkstra-0.1.1.5-56-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-2a8hKmv6f5LCw4t2cRsf0u
key:                  monad-dijkstra-0.1.1.5-2a8hKmv6f5LCw4t2cRsf0u
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  efdcebf22b40e188f171c23a07c90af2
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-2a8hKmv6f5LCw4t2cRsf0u
depends:
    base-4.16.4.0 containers-0.6.5.1 free-5.2-Hf6He7wBWKC8Hf8cYNfaCd
    mtl-2.2.2 psqueues-0.2.8.0-1SfRKz1VN7WGHAIu20THaB
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-monad-dijkstra-0.1.1.5-57-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-monad-dijkstra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 monad-dijkstra
version:              0.1.1.5
visibility:           public
id:                   monad-dijkstra-0.1.1.5-JqL0RbJwGxQEb9Fjsxj8P9
key:                  monad-dijkstra-0.1.1.5-JqL0RbJwGxQEb9Fjsxj8P9
license:              BSD-3-Clause
copyright:            Copyright (c) 2016-2023 Enno Cramer
maintainer:           Enno Cramer <ecramer@memfrob.de>
author:               Enno Cramer
homepage:             https://github.com/ennocramer/monad-dijkstra
synopsis:             A monad transformer for weighted graph searches
description:
    A monad transformer for weighted graph searches using Dijkstra'\''s or A* algorithm.

category:             Control, Monads
abi:                  29caf792bd05c0b56aadc7ca43a947c1
exposed:              True
exposed-modules:      Control.Monad.Search
import-dirs:          /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
library-dirs:         /usr/lib/ghc-9.2.8/site-local/monad-dijkstra-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-monad-dijkstra
hs-libraries:         HSmonad-dijkstra-0.1.1.5-JqL0RbJwGxQEb9Fjsxj8P9
depends:
    base-4.16.4.0 containers-0.6.5.1 free-5.2-Hd35MELMATv3ZZqiJlelay
    mtl-2.2.2 psqueues-0.2.8.0-Fb6MDcXJqVUBsdouBUX41Z
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-monad-dijkstra/html/monad-dijkstra.haddock

haddock-html:         /usr/share/doc/haskell-monad-dijkstra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
